summaryrefslogtreecommitdiff
path: root/src/model/MedalWinner.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/model/MedalWinner.cpp')
-rw-r--r--src/model/MedalWinner.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/model/MedalWinner.cpp b/src/model/MedalWinner.cpp
index 4eca811..bdf6ee3 100644
--- a/src/model/MedalWinner.cpp
+++ b/src/model/MedalWinner.cpp
@@ -14,16 +14,16 @@ bool MedalWinner::setMedals(const QJsonObject &medals) {
throw invalid_argument("Medal object of competitor is incomplete.");
}
- this->gold = medals["ME_GOLD"].toInt();
- this->silver = medals["ME_SILVER"].toInt();
- this->bronze = medals["ME_BRONZE"].toInt();
+ this->m_gold = medals["ME_GOLD"].toInt();
+ this->m_silver = medals["ME_SILVER"].toInt();
+ this->m_bronze = medals["ME_BRONZE"].toInt();
return true;
}
/**
* Static compare method, which can compare the amount of medals of two MedalWinners.
* Gold has the highest priority, then silver and finally bronze.
*
* @param lComp First competitor to compare.
* @param rComp Second competitor to compare.
@@ -14,16 +14,16 @@ bool MedalWinner::setMedals(const QJsonObject &medals) {
/**
* Static compare method, which can compare the amount of medals of two MedalWinners.
- * Gold has the highest priority, then silver and finally bronze.
+ * Gold has the highest priority, then m_silver and finally m_bronze.
*
* @param lComp First competitor to compare.